
### Sweeney, TE and Khatri, P
### Dec. 2015

### Questions: tes17 [at] stanford [dot] edu
### Website: khatrilab.stanford.edu/sepsis

### This code is to be used to test a sepsis gene expression diagnostic in the 
### available public data. These data are available under public license as 
### described by NIH GEO (ncbi.nih.gov/GEO). Included are time-matched datasets 
### that compare non-infectious SIRS to sepsis at admission. If granted access 
### to the Glue Grant, there is also data that examines longitudinal trauma cohorts. 

## load the necessary functions
source("SepsisBenchmarkFunctions.R")

## if granted access to the glue grant datasets, simply change the path to load 
## that object instead. All datasets are loaded into a list.

## Download the data file from DropBox and save it to the same folder as the scripts.
## https://www.dropbox.com/s/hxy4sevp8wd2zs9/public_sepsis_datasets.RDS

sepsisDatasets <- readRDS("public_sepsis_datasets.RDS")

## to examine the format of the data, look at the first item:
head(sepsisDatasets[[1]]$genes)
head(sepsisDatasets[[1]]$pheno)
sepsisDatasets[[1]]$class

## Each dataset has been uploaded with the publicly available phenotype data in 
## $pheno. In addition, each dataset has been given a single vector, $class, which 
## contains a 0 for a non-infectious SIRS patient, and a 1 for a sepsis patient. 
## Healthy patients are marked with NA and not included in the AUC calculations below.

## You will need to write a custom function to test a custom score. For example, 
## The functions that are used to test the 11-gene set, the FAIM3:PLAC8 ratio, and
## the Septicyte Lab are included below. There is also a placeholder for a custom
## function.

## Note that these functions will not necessarily deal gracefully with missing genes.
## Also note that some of the internal functions may be reused depending on your
## scoring mechanism.

## This code will calculate a table of AUCs for the given data. 
## Of course other sorts of analyses are also possible.

score11gene <- function(GSE){
    pos.genes <- c("CEACAM1", "ZDHHC19", "C9orf95", "GNA15", "BATF", "C3AR1")
    neg.genes <- c("KIAA1370", "TGFBI", "MTCH1", "RPGRIP1", "HLA-DPB1") 
    scoreGeomMean(GSE$genes, pos.genes, neg.genes)
}

scoreFaimPlac <- function(GSE){
    ## set negative to make the score increasing in case of infection
    -scoreRatio(GSE$genes, pos.genes = "FAIM3", neg.genes = "PLAC8")
}

scoreSepticyteLab <- function(GSE){
    pos.genes <- c("PLAC8", "LAMP1")
    neg.genes <- c("PLA2G7", "CEACAM4") 
    scoreSum(GSE$genes, pos.genes, neg.genes)
}


### This is for you to make a custom score for benchmarking
scoreCustom <- function(GSE){
    ### insert function here
    scoreCustom <- rep(1, length(GSE$class)) ## erase this placeholder
}


### Now get the scores for all datasets
sepsisDatasets <- lapply(sepsisDatasets, function(GSE){
    GSE$score11gene <- score11gene(GSE)
    GSE$scoreFaimPlac <- scoreFaimPlac(GSE)
    GSE$scoreSepticyteLab <- scoreSepticyteLab(GSE)
    GSE$scoreCustom <- scoreCustom(GSE)
    GSE
})

### To test the AUC of each score, and write to a table, we apply the following:
sepsisAUCs <- t(sapply(sepsisDatasets, function(GSE){
    AUC.11gene <- getAUC(GSE$score11gene, GSE$class)
    AUC.FaimPlac <- getAUC(GSE$scoreFaimPlac, GSE$class)
    AUC.SepticyteLab <- getAUC(GSE$scoreSepticyteLab, GSE$class)
    AUC.Custom <- getAUC(GSE$scoreCustom, GSE$class)
    c(AUC.11gene = AUC.11gene,
      AUC.FaimPlac = AUC.FaimPlac,
      AUC.SepticyteLab = AUC.SepticyteLab,
      AUC.Custom = AUC.Custom)
}))

View(sepsisAUCs)

